/*
 * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons-sandbox//i18n/src/java/org/apache/commons/i18n/LocalizedBundle.java,v 1.3 2004/12/29 17:03:55 dflorey Exp $
 * $Revision: 1.3 $
 * $Date: 2005-02-14 20:03:07 +0100 (Mo, 14 Feb 2005) $
 *
 * ====================================================================
 *
 * Copyright 2004 The Apache Software Foundation 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.commons.i18n;

import java.io.Serializable;
import java.util.Locale;

/**
 * @author Daniel Florey
 * 
 * The <code>LocalizedBundle</code> class represents a bundle of localized messages that
 * belong together.
 * The <code>LocalizedBundle</code> class itself contains the message id and the arguments
 * that might be used to include dynamic values into the message text and knows nothing
 * 
 */
public class LocalizedBundle implements Serializable {
    public final static String ID = "id";
    public final static String ARGUMENTS = "arguments";

    protected String id;
    protected Object[] arguments;

    /**
     * @param messageId The messageId refers the corresponding bundle in the file containing
     * the localized messages. The format of the message file depends on the implementation of the 
     * MessageManager.
     */
    public LocalizedBundle(String messageId) {
        this.id = messageId;
        this.arguments = new Object[0];
    }

    /**
     * @param messageId The messageId refers the corresponding bundle in the file containing
     * the localized messages. The format of the message file depends on the implementation of the 
     * MessageManager.
     * @param arguments An array of objects containing argument for the messages. These arguments
     * are used to insert dynamic values into the localized messages.
     */
    public LocalizedBundle(String messageId, Object[] arguments) {
        this.id = messageId;
        this.arguments = arguments;
    }

    /**
     * @return returns the id of this bundle
     */
    public String getId() {
        return id;
    }

    /**
     * @return returns the arguments associated with this message bundle
     */
    public Object[] getArguments() {
    	return arguments;
    }
    
    /**
     * @param key the key of the specific message entry in the message bundle
     * @param locale the locale for that this message should be rendered
     * @return returns the localized text  
     * @throws MessageNotFoundException if an entry with the given key can not be found
     * in this bundle
     */
    public String getText(String key, Locale locale) throws MessageNotFoundException {
        return MessageManager.getText(id, key, arguments, locale);
    }

    /**
     * @param key the key of the specific message entry in the message bundle
     * @param locale the locale for that this message should be rendered
     * @param defaultText the text to be returned if no entry was found for the given key
     * @return returns the localized text  
     */
    public String getText(String key, String defaultText, Locale locale) {
        return MessageManager.getText(id, key, arguments, locale, defaultText);
    }
}