/*
*
* ====================================================================
*
* Copyright 2004 The Apache Software Foundation 
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
*/
package org.apache.commons.i18n;

import java.util.Locale;
import java.util.Map;

import junit.framework.TestCase;

import org.apache.commons.i18n.bundles.MessageBundle;

/**
 * @author Daniel Florey
 *
 */
public class ResourceBundleMessageProviderTest extends TestCase {
    public ResourceBundleMessageProviderTest(String testName) {
        super(testName);
    }

    public void testInstallResourceBundle() {
        System.out.println("INSTALL RESOURCE BUNDLE");
        ResourceBundleMessageProvider.install("messageBundle");
        MessageBundle testMessage = new MessageBundle("helloWorld");
        Locale locale = Locale.GERMAN;
        assertEquals(testMessage.getTitle(locale), "Hallo Welt");
    }
    
    public void testGetEntries() {
        ResourceBundleMessageProvider.install("messageBundle");
        Map entries = new ResourceBundleMessageProvider().getEntries("helloWorld", Locale.GERMAN);
        assertTrue(entries.size() == 2 );
    }
    
    public void testFallbackToDefaultLocale() {
        ResourceBundleMessageProvider.install("messageBundle");
        Map entries = new ResourceBundleMessageProvider().getEntries("helloWorld", Locale.GERMAN);
        assertTrue(entries.size() == 2 );
    }
}